# SUS01: How do you select regions to support sustainability goals?

## References

- [AWS SUS01](https://docs.aws.amazon.com/wellarchitected/latest/framework/sus-01.html)

## Date

2025-11-27

## Focus Area

Region Selection

## Tổng quan

SUS01 tập trung vào selecting regions with lower carbon intensity.

## Best Practices

### SUS01-BP01: Choose region based on sustainability goals
Carbon-aware region selection.

## Checklist

- [ ] Carbon intensity of regions evaluated
- [ ] Sustainability goals documented
